@@ -6,14 +6,17 @@
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
-use phpseclib3\Net\SFTP;
+namespace phpseclib3\Tests\Functional\Net;
 
-class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
+use phpseclib3\Net\SFTP;
+use phpseclib3\Tests\PhpseclibFunctionalTestCase;
+
+class SFTPUserStoryTest extends PhpseclibFunctionalTestCase
 {
-    static protected $scratchDir;
-    static protected $exampleData;
-    static protected $exampleDataLength;
-    static protected $buffer;
+    protected static $scratchDir;
+    protected static $exampleData;
+    protected static $exampleDataLength;
+    protected static $buffer;
 
     public static function setUpBeforeClass()
     {
@@ -135,7 +138,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
         return $sftp;
     }
 
-    static function demoCallback($length)
+    public static function demoCallback($length)
     {
         $r = substr(self::$buffer, 0, $length);
         self::$buffer = substr(self::$buffer, $length);
@@ -486,6 +489,7 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
 
     /**
      * on older versions this would result in a fatal error
+     *
      * @depends testStatOnCWD
      * @group github402
      */
@@ -764,7 +768,11 @@ class Functional_Net_SFTPUserStoryTest extends PhpseclibFunctionalTestCase
 
         $list_cache_disabled = $sftp->rawlist('.', true);
 
-        $this->assertEquals($list_cache_enabled, $list_cache_disabled, 'The files should be the same regardless of stat cache', 0.0, 10, true);
+        $this->assertEquals(
+            $list_cache_enabled,
+            $list_cache_disabled,
+            'The files should be the same regardless of stat cache'
+        );
 
         return $sftp;
     }
