@@ -1,20 +1,24 @@
 <?php
+
 /**
  * @author    Jim Wigginton <terrafrost@php.net>
  * @copyright 2013 Jim Wigginton
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
+namespace phpseclib3\Tests\Unit\Crypt\EC;
+
 use phpseclib3\Crypt\EC;
+use phpseclib3\Crypt\EC\Formats\Keys\OpenSSH;
 use phpseclib3\Crypt\EC\Formats\Keys\PKCS1;
 use phpseclib3\Crypt\EC\Formats\Keys\PKCS8;
 use phpseclib3\Crypt\EC\Formats\Keys\PuTTY;
-use phpseclib3\Crypt\EC\Formats\Keys\OpenSSH;
 use phpseclib3\Crypt\EC\Formats\Keys\XML;
-use phpseclib3\Crypt\PublicKeyLoader;
 use phpseclib3\Crypt\EC\PrivateKey;
+use phpseclib3\Crypt\PublicKeyLoader;
+use phpseclib3\Tests\PhpseclibTestCase;
 
-class Unit_Crypt_EC_KeyTest extends PhpseclibTestCase
+class KeyTest extends PhpseclibTestCase
 {
     public function testBinaryPKCS1PrivateParameters()
     {
@@ -271,9 +275,11 @@ MCwwBwYDK2VwBQADIQAZv0QJaYTN/oVBusFn3DuWyFCGqjC2tssMXDitcDFm4Q==
     public function testEd25519PrivateKey()
     {
         // without public key (public key should be derived)
-        $key = PublicKeyLoader::load('-----BEGIN PRIVATE KEY-----
+        $expected = '-----BEGIN PRIVATE KEY-----
 MC4CAQAwBQYDK2VwBCIEINTuctv5E1hK1bbY8fdp+K06/nwoy/HU++CXqI9EdVhC
------END PRIVATE KEY-----');
+-----END PRIVATE KEY-----';
+        $key = PublicKeyLoader::load($expected);
+        $this->assertSameNL($expected, $key->toString('PKCS8'));
         $this->assertSameNL('Ed25519', $key->getCurve());
         $this->assertSameNL('Ed25519', $key->getPublicKey()->getCurve());
 
@@ -289,14 +295,10 @@ Z9w7lshQhqowtrbLDFw4rXAxZuE=
         // the above key not only omits NULL - it also includes a
         // unstructuredName attribute with a value of "Curdle Chairs"
         // that the following key does not have
-        $expected = '-----BEGIN PRIVATE KEY-----
+        $key = PublicKeyLoader::load('-----BEGIN PRIVATE KEY-----
 MFMCAQEwBwYDK2VwBQAEIgQg1O5y2/kTWErVttjx92n4rTr+fCjL8dT74Jeoj0R1
 WEKBIQAZv0QJaYTN/oVBusFn3DuWyFCGqjC2tssMXDitcDFm4Q==
------END PRIVATE KEY-----';
-        $this->assertSameNL($expected, $key->toString('PKCS8'));
-
-        $expected = EC::createKey('Ed25519')->toString('PKCS8');
-        $key = PublicKeyLoader::load($expected);
+-----END PRIVATE KEY-----');
         $this->assertSameNL('Ed25519', $key->getCurve());
         $this->assertSameNL('Ed25519', $key->getPublicKey()->getCurve());
     }
@@ -350,7 +352,6 @@ Private-MAC: 97a990a3d5f6b8f268d4be9c4ab9ebfd8fa79849
 
         OpenSSH::setComment('ecdsa-key-20181105');
         $this->assertSameNL($expected, $key->toString('OpenSSH'));
-
     }
 
     public function testPuTTYnistp521()
@@ -460,7 +461,7 @@ pomV7r6gmoMYteGVABfgAAAAD3ZhZ3JhbnRAdmFncmFudAECAwQFBg==
 
         XML::enableRFC4050Syntax();
 
-        $dom = new DOMDocument();
+        $dom = new \DOMDocument();
         $dom->preserveWhiteSpace = false;
         $dom->loadXML($orig);
         $expected = $dom->C14N();
