@@ -1,13 +1,17 @@
 <?php
+
 /**
  * @author    Jim Wigginton <terrafrost@php.net>
  * @copyright 2014 Jim Wigginton
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
-use phpseclib3\File\ASN1;
+namespace phpseclib3\Tests\Unit\File;
 
-class Unit_File_ASN1Test extends PhpseclibTestCase
+use phpseclib3\File\ASN1;
+use phpseclib3\Tests\PhpseclibTestCase;
+
+class ASN1Test extends PhpseclibTestCase
 {
     /**
      * on older versions of \phpseclib3\File\ASN1 this would yield a PHP Warning
@@ -290,29 +294,32 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
     public function testInfiniteLoop()
     {
         $data = base64_decode('MD6gJQYKKwYBBAGCNxQCA6AXDBVvZmZpY2VAY2VydGRpZ2l0YWwucm+BFW9mZmljZUBjZXJ0ZGlnaXRhbC5ybw==');
-        ASN1::decodeBER($data);
+        self::assertSame(
+            'a:1:{i:0;a:5:{s:5:"start";i:0;s:12:"headerlength";i:2;s:4:"type";i:16;s:7:"content";a:2:{i:0;a:6:{s:4:"type";i:2;s:8:"constant";i:0;s:7:"content";a:2:{i:0;a:5:{s:5:"start";i:4;s:12:"headerlength";i:2;s:4:"type";i:6;s:7:"content";s:22:"1.3.6.1.4.1.311.20.2.3";s:6:"length";i:12;}i:1;a:6:{s:4:"type";i:2;s:8:"constant";i:0;s:7:"content";a:1:{i:0;a:5:{s:5:"start";i:18;s:12:"headerlength";i:2;s:4:"type";i:12;s:7:"content";s:21:"office@certdigital.ro";s:6:"length";i:23;}}s:6:"length";i:25;s:5:"start";i:16;s:12:"headerlength";i:2;}}s:6:"length";i:39;s:5:"start";i:2;s:12:"headerlength";i:2;}i:1;a:6:{s:4:"type";i:2;s:8:"constant";i:1;s:7:"content";s:21:"office@certdigital.ro";s:6:"length";i:23;s:5:"start";i:41;s:12:"headerlength";i:2;}}s:6:"length";i:64;}}',
+            serialize(ASN1::decodeBER($data))
+        );
     }
 
     public function testMaps()
     {
         $files = scandir('phpseclib/File/ASN1/Maps');
+        self::assertNotEmpty($files);
         foreach ($files as $file) {
             if ($file == '.' || $file == '..') {
                 continue;
             }
-
-            constant('phpseclib3\\File\\ASN1\\Maps\\' . basename($file, '.php') . '::MAP');
+            self::assertTrue(defined('phpseclib3\\File\\ASN1\\Maps\\' . basename($file, '.php') . '::MAP'));
         }
     }
 
     public function testApplicationTag()
     {
-        $map = array(
+        $map = [
             'type'     => ASN1::TYPE_SEQUENCE,
-            'children' => array(
+            'children' => [
                 // technically, default implies optional, but we'll define it as being optional, none-the-less, just to
                 // reenforce that fact
-                'version'             => array(
+                'version'             => [
                     // if class isn't present it's assumed to be ASN1::CLASS_UNIVERSAL or
                     // (if constant is present) ASN1::CLASS_CONTEXT_SPECIFIC
                     'class'    => ASN1::CLASS_APPLICATION,
@@ -321,12 +328,12 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
                     'explicit' => true,
                     'default'  => 'v1',
                     'type'     => ASN1::TYPE_INTEGER,
-                    'mapping' => array('v1', 'v2', 'v3')
-                )
-            )
-        );
+                    'mapping' => ['v1', 'v2', 'v3']
+                ]
+            ]
+        ];
 
-        $data = array('version' => 'v3');
+        $data = ['version' => 'v3'];
 
         $str = ASN1::encodeDER($data, $map);
 
@@ -342,7 +349,10 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
     public function testInvalidCertificate()
     {
         $data = 'a' . base64_decode('MD6gJQYKKwYBBAGCNxQCA6AXDBVvZmZpY2VAY2VydGRpZ2l0YWwucm+BFW9mZmljZUBjZXJ0ZGlnaXRhbC5ybw==');
-        ASN1::decodeBER($data);
+        self::assertSame(
+            'a:1:{i:0;a:6:{s:4:"type";i:1;s:8:"constant";i:1;s:7:"content";a:0:{}s:6:"length";i:2;s:5:"start";i:0;s:12:"headerlength";i:2;}}',
+            serialize(ASN1::decodeBER($data))
+        );
     }
 
     /**
@@ -370,21 +380,21 @@ class Unit_File_ASN1Test extends PhpseclibTestCase
      */
     public function testExplicitImplicitDate()
     {
-        $map = array(
+        $map = [
             'type'     => ASN1::TYPE_SEQUENCE,
-            'children' => array(
-                'notBefore' => array(
+            'children' => [
+                'notBefore' => [
                                              'constant' => 0,
                                              'optional' => true,
                                              'implicit' => true,
-                                             'type' => ASN1::TYPE_GENERALIZED_TIME),
-                'notAfter'  => array(
+                                             'type' => ASN1::TYPE_GENERALIZED_TIME],
+                'notAfter'  => [
                                              'constant' => 1,
                                              'optional' => true,
                                              'implicit' => true,
-                                             'type' => ASN1::TYPE_GENERALIZED_TIME)
-            )
-        );
+                                             'type' => ASN1::TYPE_GENERALIZED_TIME]
+            ]
+        ];
 
         $a = pack('H*', '3026a011180f32303137303432313039303535305aa111180f32303138303432313230353935395a');
         $a = ASN1::decodeBER($a);
