@@ -1,17 +1,21 @@
 <?php
+
 /**
  * @author    Jim Wigginton <terrafrost@php.net>
  * @copyright 2014 Jim Wigginton
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
+namespace phpseclib3\Tests\Unit\File\X509;
+
+use phpseclib3\Crypt\PublicKeyLoader;
+use phpseclib3\Crypt\RSA;
 use phpseclib3\File\ASN1;
 use phpseclib3\File\ASN1\Element;
 use phpseclib3\File\X509;
-use phpseclib3\Crypt\RSA;
-use phpseclib3\Crypt\PublicKeyLoader;
+use phpseclib3\Tests\PhpseclibTestCase;
 
-class Unit_File_X509_X509Test extends PhpseclibTestCase
+class X509Test extends PhpseclibTestCase
 {
     public function testExtensionMapping()
     {
@@ -137,7 +141,7 @@ IOkKcGQRCMha8X2e7GmlpdWC1ycenlbN0nbVeSv3JUMcafC4+Q==
         $value = ASN1::encodeOID('1.2.3.4');
         $ext = chr(ASN1::TYPE_OBJECT_IDENTIFIER) . ASN1::encodeLength(strlen($value)) . $value;
         $value = 'zzzzzzzzz';
-        $ext.= chr(ASN1::TYPE_OCTET_STRING) . ASN1::encodeLength(strlen($value)) . $value;
+        $ext .= chr(ASN1::TYPE_OCTET_STRING) . ASN1::encodeLength(strlen($value)) . $value;
         $ext = chr(ASN1::TYPE_SEQUENCE | 0x20) . ASN1::encodeLength(strlen($ext)) . $ext;
 
         $cert['tbsCertificate']['extensions'][4] = new Element($ext);
@@ -375,6 +379,7 @@ Mj93S
 
         $x509 = new X509();
         $x509->sign($issuer, $subject);
+        self::assertTrue(true);
     }
 
     public function testUtcTimeWithoutSeconds()
@@ -1045,7 +1050,7 @@ ut3+b2Xvzq8yzmHMFtLIJ6Afu1jJpqD82BUAFcvi5vhnP8M7b974R18WCOpgNQvXDI+2/8ZINeU=
 -----END CERTIFICATE-----');
         $r = $x509->saveX509($r);
         $r = $x509->loadX509($r);
-        $this->assertSame($r['tbsCertificate']['extensions'][5]['extnValue']['excludedSubtrees'][1]['base']['iPAddress'], array('0.0.0.0', '0.0.0.0'));
+        $this->assertSame($r['tbsCertificate']['extensions'][5]['extnValue']['excludedSubtrees'][1]['base']['iPAddress'], ['0.0.0.0', '0.0.0.0']);
     }
 
     /**
@@ -1188,7 +1193,7 @@ qzFkAKWjJj4KjfrbZX4C0Spfxw==
         $key = ASN1::encodeDER($key, ['type' => ASN1::TYPE_BIT_STRING]);
         $key = new Element($key);
 
-        $x509 = new X509;
+        $x509 = new X509();
         $this->assertIsString($x509->computeKeyIdentifier($key));
     }
 
@@ -1240,15 +1245,15 @@ QwinX0cR9Hx84rSMrFndxZi52o9EOLJ7cithncoW1KOAf7lIJIUzP0oIKkskAndQ
 o2UiZsxgoMYuq02T07DOknc=
 -----END ENCRYPTED PRIVATE KEY-----', 'demo');
 
-        $subject = new X509;
+        $subject = new X509();
         $subject->setDNProp('id-at-organizationName', 'phpseclib demo cert');
         $subject->setPublicKey($private->getPublicKey());
 
-        $issuer = new X509;
+        $issuer = new X509();
         $issuer->setPrivateKey($private);
         $issuer->setDNProp('id-at-organizationName', 'phpseclib CA cert');
 
-        $x509 = new X509;
+        $x509 = new X509();
         $x509->sign($issuer, $subject);
     }
 
